==================================
``psyclone.psyir.nodes.statement``
==================================

.. automodule:: psyclone.psyir.nodes.statement

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.statement


Classes
=======

- :py:class:`Statement`:
  Abstract node representing a general PSyIR Statement.


.. autoclass:: Statement
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Statement
      :parts: 1
